@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@
 NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Configure Notes Agent"));
+    setWindowTitle(i18nc("@title:window", "Configure Notes Agent"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setModal(true);
@@ -71,7 +71,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
         QStringLiteral(KNOTES_VERSION),
         i18n("Notes Agent."),
         KAboutLicense::GPL_V2,
-        i18n("Copyright (C) 2013-2019 Laurent Montel"));
+        i18n("Copyright (C) 2013-2020 Laurent Montel"));
 
     aboutData.addAuthor(i18n("Laurent Montel"),
                         i18n("Maintainer"), QStringLiteral("montel@kde.org"));
