@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,14 +29,12 @@ class QTcpServer;
 class QTimer;
 namespace NoteShared {
 class NotesChangeRecorder;
-class NotesAkonadiTreeModel;
 }
 
 namespace Akonadi {
 class Session;
 }
 
-class QModelIndex;
 class NotesManager : public QObject
 {
     Q_OBJECT
