@@ -30,12 +30,9 @@
 #include "config/notenetworkconfig.h"
 #include "print/knoteprintselectthemecombobox.h"
 
-#include <kconfigwidgets_version.h>
 #include <KAuthorized>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KNS3/DownloadDialog>
-#include <KWindowSystem>
 
 #include <QCheckBox>
 #include <QApplication>
@@ -54,13 +51,6 @@ KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     button(QDialogButtonBox::Ok)->setDefault(true);
 
     setWindowTitle(title);
-    KWindowSystem::setIcons(winId(),
-                            qApp->windowIcon().pixmap(
-                                IconSize(KIconLoader::Desktop),
-                                IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(
-                                IconSize(KIconLoader::Small),
-                                IconSize(KIconLoader::Small)));
     addModule(QStringLiteral("knote_config_display"));
     addModule(QStringLiteral("knote_config_editor"));
     addModule(QStringLiteral("knote_config_action"));
@@ -211,11 +201,7 @@ KNoteMiscConfig::KNoteMiscConfig(QWidget *parent)
     howItWorks->setContextMenuPolicy(Qt::NoContextMenu);
     lay->addStretch();
     load();
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-    connect(mDefaultTitle, &QLineEdit::textChanged, this, qOverload<>(&KNoteMiscConfig::changed));
-#else
     connect(mDefaultTitle, &QLineEdit::textChanged, this, &KNoteMiscConfig::markAsChanged);
-#endif
 }
 
 void KNoteMiscConfig::load()
@@ -322,11 +308,7 @@ KNoteCollectionConfig::KNoteCollectionConfig(QWidget *parent)
     QHBoxLayout *lay = new QHBoxLayout(this);
     mCollectionConfigWidget = new KNoteCollectionConfigWidget;
     lay->addWidget(mCollectionConfigWidget);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-    connect(mCollectionConfigWidget, &KNoteCollectionConfigWidget::emitChanged, this, qOverload<>(&KNoteCollectionConfig::changed));
-#else
     connect(mCollectionConfigWidget, &KNoteCollectionConfigWidget::emitChanged, this, &KNoteCollectionConfig::markAsChanged);
-#endif
     load();
 }
 
