@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,10 +27,8 @@
 #include "attributes/notelockattribute.h"
 
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KWindowSystem>
 
 #include <QApplication>
 #include <QDialogButtonBox>
@@ -50,14 +48,6 @@ KNoteSimpleConfigDialog::KNoteSimpleConfigDialog(const QString &title, QWidget *
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KNoteSimpleConfigDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &KNoteSimpleConfigDialog::reject);
 
-    setWindowTitle(title);
-    KWindowSystem::setIcons(winId(),
-                            qApp->windowIcon().pixmap(
-                                IconSize(KIconLoader::Desktop),
-                                IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(
-                                IconSize(KIconLoader::Small),
-                                IconSize(KIconLoader::Small)));
     mTabWidget = new QTabWidget;
 
     mEditorConfigWidget = new KNoteEditorConfigWidget(this);
