@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,6 +33,7 @@
 #include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <KConfigGroup>
+#include <QMenu>
 
 KNoteFindDialog::KNoteFindDialog(QWidget *parent)
     : QDialog(parent)
@@ -99,9 +100,11 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
 
     //Result
     mNoteList = new NoteShared::NoteListWidget(this);
+    mNoteList->setContextMenuPolicy(Qt::CustomContextMenu);
     mNoteList->setSelectionMode(QAbstractItemView::SingleSelection);
     connect(mNoteList, &NoteShared::NoteListWidget::itemDoubleClicked,
             this, &KNoteFindWidget::slotItemDoubleClicked);
+    connect(mNoteList, &NoteShared::NoteListWidget::customContextMenuRequested, this, &KNoteFindWidget::customContextMenuRequested);
     vbox->addWidget(mNoteList);
 
     mResultSearch = new QLabel(this);
@@ -156,3 +159,15 @@ void KNoteFindWidget::slotTextChanged(const QString &text)
 {
     mSearchButton->setEnabled(!text.trimmed().isEmpty());
 }
+
+void KNoteFindWidget::customContextMenuRequested(const QPoint &)
+{
+    QListWidgetItem *item = mNoteList->currentItem();
+    QMenu menu(this);
+    if (item) {
+        menu.addAction(i18n("Show Note"), this, [this, item]() {
+            Q_EMIT noteSelected(mNoteList->itemId(item));
+        });
+        menu.exec(QCursor::pos());
+    }
+}
