@@ -75,7 +75,7 @@
 #include <QMenu>
 
 KNotesPart::KNotesPart(QObject *parent)
-    : KParts::ReadOnlyPart(parent)
+    : KParts::Part(parent)
     , mNotesWidget(nullptr)
     , mPublisher(nullptr)
     , mNotePrintPreview(nullptr)
@@ -333,6 +333,7 @@ void KNotesPart::printSelectedNotes(bool preview)
     }
     if (!printingTheme.isEmpty()) {
         QList<KNotePrintObject *> listPrintObj;
+        listPrintObj.reserve(lst.count());
         for (QListWidgetItem *item : lst) {
             listPrintObj.append(new KNotePrintObject(static_cast<KNotesIconViewItem *>(item)->item()));
         }
@@ -342,11 +343,6 @@ void KNotesPart::printSelectedNotes(bool preview)
     }
 }
 
-bool KNotesPart::openFile()
-{
-    return false;
-}
-
 // public KNotes D-Bus interface implementation
 
 void KNotesPart::newNote(const QString &name, const QString &text)
@@ -451,7 +447,7 @@ void KNotesPart::killSelectedNotes()
         return;
     }
     QList<KNotesIconViewItem *> items;
-
+    items.reserve(lst.count());
     for (QListWidgetItem *item : lst) {
         KNotesIconViewItem *knivi = static_cast<KNotesIconViewItem *>(item);
         items.append(knivi);
