@@ -30,8 +30,6 @@
 
 #include "knotes-version.h"
 
-#include <Libkdepim/MaillistDrag>
-using namespace KPIM;
 using namespace KCalUtils;
 using namespace KCalendarCore;
 
@@ -50,7 +48,7 @@ using namespace KCalendarCore;
 #include <QDropEvent>
 #include <QStandardPaths>
 
-EXPORT_KONTACT_PLUGIN(KNotesPlugin, knotes)
+EXPORT_KONTACT_PLUGIN_WITH_JSON(KNotesPlugin, "knotesplugin.json")
 
 KNotesPlugin::KNotesPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "knotes")
@@ -83,7 +81,7 @@ bool KNotesPlugin::isRunningStandalone() const
     return mUniqueAppWatcher->isRunningStandalone();
 }
 
-KParts::ReadOnlyPart *KNotesPlugin::createPart()
+KParts::Part *KNotesPlugin::createPart()
 {
     return new KNotesPart(this);
 }
@@ -120,7 +118,6 @@ bool KNotesPlugin::canDecodeMimeData(const QMimeData *mimeData) const
 {
     return
         mimeData->hasText()
-        || MailList::canDecode(mimeData)
         || KContacts::VCardDrag::canDecode(mimeData)
         || ICalDrag::canDecode(mimeData);
 }
@@ -178,23 +175,6 @@ void KNotesPlugin::processDropEvent(QDropEvent *event)
         return;
     }
 
-    if (MailList::canDecode(md)) {
-        MailList mails = MailList::fromMimeData(md);
-        event->accept();
-        if (mails.count() != 1) {
-            KMessageBox::sorry(
-                core(),
-                i18nc("@info", "Dropping multiple mails is not supported."));
-        } else {
-            MailSummary mail = mails.constFirst();
-            const QString txt = i18nc("@item", "From: %1\nTo: %2\nSubject: %3",
-                                      mail.from(), mail.to(), mail.subject());
-            static_cast<KNotesPart *>(part())->newNote(
-                i18nc("@item", "Mail: %1", mail.subject()), txt);
-        }
-        return;
-    }
-
     qCWarning(KNOTES_KONTACT_PLUGIN_LOG) << QStringLiteral("Cannot handle drop events of type '%1'.").arg(event->mimeData()->formats().join(QLatin1Char(';')));
 }
 
