@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,13 +19,13 @@
 #ifndef KNOTEINTERFACE_H
 #define KNOTEINTERFACE_H
 #include "knotes_export.h"
-
+#include <QObject>
 class KNOTES_EXPORT KNoteInterface
 {
 public:
     KNoteInterface();
     void setBlockSave(bool b);
-    bool blockSave() const;
+    Q_REQUIRED_RESULT bool blockSave() const;
 
 protected:
     bool mBlockSave;
