@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@ public:
     explicit KNoteGrantleePrint(const QString &themePath);
     ~KNoteGrantleePrint();
 
-    QString notesToHtml(const QList<KNotePrintObject *> &lst);
+    Q_REQUIRED_RESULT QString notesToHtml(const QList<KNotePrintObject *> &lst);
 };
 
 #endif // KNOTEGRANTLEEPRINT_H
