@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ public:
     explicit KNotePrintSelectThemeComboBox(QWidget *parent = nullptr);
     ~KNotePrintSelectThemeComboBox();
 
-    QString selectedTheme() const;
+    Q_REQUIRED_RESULT QString selectedTheme() const;
 
     void loadThemes();
     void selectDefaultTheme();
