@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ public:
     explicit KNotePrintSelectThemeDialog(QWidget *parent = nullptr);
     ~KNotePrintSelectThemeDialog();
 
-    QString selectedTheme() const;
+    Q_REQUIRED_RESULT QString selectedTheme() const;
 
 private:
     KNotePrintSelectThemeComboBox *mThemes = nullptr;
